@@ -102,7 +102,7 @@ class RabbitMQClient:
         self._monitor_task: Optional[asyncio.Task] = None
 
         # 消息处理跟踪
-        self._processing_message_ids: Set[str] = set()
+        self._tracking_messages: Dict[str, Dict[str, Any]] = {}
 
     @property
     def is_connected(self) -> bool:
@@ -189,7 +189,7 @@ class RabbitMQClient:
         """
         从连接池获取资源并初始化（交换机、队列）
         """
-        logger.debug(
+        logger.info(
             f"连接参数 - force_reconnect={force_reconnect}, "
             f"declare_queue={declare_queue}, create_if_not_exists={self.create_if_not_exists}"
         )
@@ -275,7 +275,7 @@ class RabbitMQClient:
                     # 不声明队列时的状态处理
                     self.queue = None
                     self.actual_queue_name = None
-                    logger.debug(f"跳过队列 '{self.queue_name}' 的声明和绑定")
+                    logger.info(f"跳过队列 '{self.queue_name}' 的声明和绑定")
 
                 # 验证连接状态
                 if not self.is_connected:
@@ -320,13 +320,27 @@ class RabbitMQClient:
                         await self._recreate_channel()
                         continue
 
+                    # 清理已确认的消息记录
+                    if self._tracking_messages:
+                        # 收集所有已确认的消息ID
+                        acked_message_ids = [
+                            msg_id for msg_id, msg_info in self._tracking_messages.items()
+                            if msg_info.get('acked', False)
+                        ]
+                        # 移除已确认的消息
+                        for msg_id in acked_message_ids:
+                            del self._tracking_messages[msg_id]
+                        if acked_message_ids:
+                            logger.info(
+                                f"清理了 {len(acked_message_ids)} 条已确认的消息跟踪记录")
+
                     # 检查消费停滞
                     if self._is_consuming:
                         current_time = asyncio.get_event_loop().time()
                         if current_time - self._last_message_processed > self.consumption_stall_threshold:
-                            if self._processing_message_ids:
-                                logger.warning(
-                                    f"消费停滞，但有 {len(self._processing_message_ids)} 个消息正在处理，暂不重启")
+                            if self._tracking_messages:
+                                logger.info(
+                                    f"消费停滞，但有 {len(self._tracking_messages)} 个消息正在处理，暂不重启")
                             else:
                                 # 确实无消息处理，再重启
                                 await self.stop_consuming()
@@ -336,7 +350,7 @@ class RabbitMQClient:
                     logger.error(f"监控任务出错: {str(e)}")
                     await asyncio.sleep(1)
 
-                await asyncio.sleep(30)
+                await asyncio.sleep(60)
 
         self._monitor_task = asyncio.create_task(monitor())
 
@@ -375,7 +389,7 @@ class RabbitMQClient:
                 current_time = asyncio.get_event_loop().time()
                 # 检查是否超过指定时间无活动
                 if current_time - self._last_activity_timestamp > self.connection_pool.heartbeat * 1.5:
-                    logger.debug(
+                    logger.info(
                         f"连接 {self.connection_pool.heartbeat*1.5}s 无活动，执行保活检查")
                     try:
                         if self.channel.is_closed:
@@ -440,7 +454,7 @@ class RabbitMQClient:
         self.exchange = None
         self.queue = None
         self._consumer_tag = None
-        self._processing_message_ids.clear()
+        self._tracking_messages.clear()
 
         logger.info("RabbitMQ客户端已关闭")
 
@@ -488,13 +502,13 @@ class RabbitMQClient:
                         message,
                         routing_key=routing_key or self.routing_key or '#',
                         mandatory=True,
-                        timeout=15.0
+                        timeout=5.0
                     )
                     if not confirmed:
                         raise Exception("消息未被服务器确认接收")
 
                 self._update_activity_timestamp()
-                logger.debug(f"消息已发布到交换机 '{self.exchange_name}'")
+                logger.info(f"消息已发布到交换机 '{self.exchange_name}'")
                 return
             except (ConnectionClosed, ChannelInvalidStateError):
                 retry_count += 1
@@ -514,7 +528,7 @@ class RabbitMQClient:
 
     async def start_consuming(self) -> ConsumerTag:
         if self._is_consuming:
-            logger.debug("已经在消费中，返回现有consumer_tag")
+            logger.info("已经在消费中，返回现有consumer_tag")
             if self._consumer_tag:
                 return self._consumer_tag
             # 如果_is_consuming为True但无consumer_tag，重置状态并重新启动
@@ -577,15 +591,15 @@ class RabbitMQClient:
             await self._safe_cancel_consumer()
 
         # 等待所有正在处理的消息完成
-        if self._processing_message_ids:
+        if self._tracking_messages:
             logger.info(
-                f"等待 {len(self._processing_message_ids)} 个正在处理的消息完成...")
-            while self._processing_message_ids and not self._closed:
-                await asyncio.sleep(0.1)
+                f"等待 {len(self._tracking_messages)} 个正在处理的消息完成...")
+            while self._tracking_messages and not self._closed:
+                await asyncio.sleep(1)
 
         # 清理状态
         self._consumer_tag = None
-        self._processing_message_ids.clear()
+        self._tracking_messages.clear()
 
         logger.info(f"已停止消费队列: {self.actual_queue_name}")
 
@@ -615,23 +629,29 @@ class RabbitMQClient:
             return
 
         message_id = message.message_id or str(id(message))
-        if message_id in self._processing_message_ids:
+        if message_id in self._tracking_messages:
             logger.warning(f"检测到重复处理的消息ID: {message_id}，直接确认")
             await message.ack()
             return
 
-        self._processing_message_ids.add(message_id)
+        # 记录消息跟踪信息
+        self._tracking_messages[message_id] = {
+            'delivery_tag': message.delivery_tag,
+            'acked': False,
+            'channel_number': self.channel.number if self.channel else None
+        }
 
         try:
-            logger.debug(f"收到队列 {self.actual_queue_name} 的消息: {message_id}")
+            logger.info(f"收到队列 {self.actual_queue_name} 的消息: {message_id}")
 
             parsed_data = await self._parse_message(message)
             await self.message_handler(MQMsgModel(** parsed_data), message)
 
             await message.ack()
+            self._tracking_messages[message_id]['acked'] = True  # 更新ACK状态
             self._update_activity_timestamp()
             self._update_message_processed_timestamp()
-            logger.debug(f"消息 {message_id} 处理完成并确认")
+            logger.info(f"消息 {message_id} 处理完成并确认")
 
         except Exception as e:
             current_headers = message.headers or {}
@@ -647,6 +667,7 @@ class RabbitMQClient:
                 logger.error(
                     f"消息 {message_id} 已达到最大重试次数({MAX_RETRY_COUNT}次)，标记为失败")
                 await message.ack()
+                self._tracking_messages[message_id]['acked'] = True  # 更新ACK状态
                 self._update_activity_timestamp()
                 return
 
@@ -661,6 +682,7 @@ class RabbitMQClient:
             )
 
             await message.reject(requeue=False)
+            self._tracking_messages[message_id]['acked'] = True  # 拒绝也算处理完成
 
             if self.exchange:
                 await self.exchange.publish(
@@ -672,8 +694,8 @@ class RabbitMQClient:
                 self._update_activity_timestamp()
                 logger.info(f"消息 {message_id} 已重新发布，当前重试次数: {retry_count}")
         finally:
-            if message_id in self._processing_message_ids:
-                self._processing_message_ids.remove(message_id)
+            if message_id in self._tracking_messages:
+                del self._tracking_messages[message_id]
 
     async def __aenter__(self):
         await self.connect()
