@@ -142,7 +142,7 @@ class RabbitMQService:
             else:
                 logger.info(f"监听器队列已包含app-name: {processed_queue_name}")
 
-        logger.debug(
+        logger.info(
             f"创建客户端 - 队列: {processed_queue_name}, 发送器: {is_sender}, "
             f"允许创建: {create_if_not_exists}"
         )
@@ -161,13 +161,13 @@ class RabbitMQService:
             auto_parse_json=kwargs.get('auto_parse_json', True),
             create_if_not_exists=create_if_not_exists,
             connection_timeout=kwargs.get('connection_timeout', 10),
-            rpc_timeout=kwargs.get('rpc_timeout', 5),
+            rpc_timeout=kwargs.get('rpc_timeout', 10),
             reconnection_delay=kwargs.get('reconnection_delay', 1),
             max_reconnection_attempts=kwargs.get(
                 'max_reconnection_attempts', 5),
             prefetch_count=kwargs.get('prefetch_count', 2),
             consumption_stall_threshold=kwargs.get(
-                'consumption_stall_threshold', 10)
+                'consumption_stall_threshold', 10),
         )
 
         # 使用declare_queue控制是否声明队列（发送器不声明，监听器声明）
@@ -207,12 +207,12 @@ class RabbitMQService:
                 if client.is_connected:
                     # 如果是监听器但队列未初始化，重新连接
                     if not is_sender and not client.queue:
-                        logger.debug(f"客户端 '{client_name}' 队列未初始化，重新连接")
+                        logger.info(f"客户端 '{client_name}' 队列未初始化，重新连接")
                         client.create_if_not_exists = True
                         await client.connect(force_reconnect=True, declare_queue=True)
                     return client
                 else:
-                    logger.debug(f"客户端 '{client_name}' 连接已关闭，重新连接")
+                    logger.info(f"客户端 '{client_name}' 连接已关闭，重新连接")
                     if not is_sender:
                         client.create_if_not_exists = True
                     await client.connect(declare_queue=not is_sender)
@@ -240,7 +240,7 @@ class RabbitMQService:
 
             # 检查队列是否已初始化
             if initial_queue_name in cls._initialized_queues:
-                logger.debug(f"队列 '{initial_queue_name}' 已初始化，直接创建客户端")
+                logger.info(f"队列 '{initial_queue_name}' 已初始化，直接创建客户端")
                 client = await cls._create_client(
                     initial_queue_name, ** kwargs
                 )
@@ -276,7 +276,7 @@ class RabbitMQService:
 
     # 以下方法逻辑与原有保持一致（无需修改）
     @classmethod
-    async def setup_senders(cls, senders: List[RabbitMQSendConfig], has_listeners: bool = False) -> None:
+    async def setup_senders(cls, senders: List[RabbitMQSendConfig], has_listeners: bool = False, ** kwargs) -> None:
         """设置消息发送器"""
         cls._has_senders = True
         cls._has_listeners = has_listeners
@@ -287,6 +287,7 @@ class RabbitMQService:
                 if not sender_config.queue_name:
                     raise ValueError(f"发送器配置第{idx+1}项缺少queue_name")
 
+                prefetch_count = sender_config.prefetch_count
                 queue_name = sender_config.queue_name
                 app_name = cls._config.get(
                     "APP_NAME", "") if cls._config else ""
@@ -295,11 +296,11 @@ class RabbitMQService:
                 normalized_name = queue_name
                 if app_name and normalized_name.endswith(f".{app_name}"):
                     normalized_name = normalized_name[:-len(f".{app_name}")]
-                    logger.debug(f"发送器队列名称移除app-name后缀: {normalized_name}")
+                    logger.info(f"发送器队列名称移除app-name后缀: {normalized_name}")
 
                 # 检查是否已初始化
                 if normalized_name in cls._sender_client_names:
-                    logger.debug(f"发送客户端 '{normalized_name}' 已存在，跳过")
+                    logger.info(f"发送客户端 '{normalized_name}' 已存在，跳过")
                     continue
 
                 # 获取或创建客户端
@@ -315,7 +316,9 @@ class RabbitMQService:
                         auto_delete=sender_config.auto_delete,
                         auto_parse_json=sender_config.auto_parse_json,
                         queue_name=queue_name,
-                        create_if_not_exists=False
+                        create_if_not_exists=False,
+                        prefetch_count=prefetch_count,
+                        ** kwargs
                     )
 
                 # 记录客户端
@@ -334,7 +337,7 @@ class RabbitMQService:
         logger.info(f"消息发送器设置完成，共 {len(cls._sender_client_names)} 个发送器")
 
     @classmethod
-    async def setup_listeners(cls, listeners: List[RabbitMQListenerConfig], has_senders: bool = False) -> None:
+    async def setup_listeners(cls, listeners: List[RabbitMQListenerConfig], has_senders: bool = False, ** kwargs) -> None:
         """设置消息监听器"""
         cls._has_listeners = True
         cls._has_senders = has_senders
@@ -402,7 +405,7 @@ class RabbitMQService:
             raise ValueError("RabbitMQService尚未初始化，请先调用init方法")
 
         if queue_name in cls._message_handlers:
-            logger.debug(f"监听器 '{queue_name}' 已存在，跳过重复添加")
+            logger.info(f"监听器 '{queue_name}' 已存在，跳过重复添加")
             return
 
         # 创建并初始化客户端
@@ -426,7 +429,7 @@ class RabbitMQService:
     async def start_consumer(cls, client_name: str) -> None:
         """启动指定客户端的消费者"""
         if client_name in cls._consumer_tasks and not cls._consumer_tasks[client_name].done():
-            logger.debug(f"消费者 '{client_name}' 已在运行中，无需重复启动")
+            logger.info(f"消费者 '{client_name}' 已在运行中，无需重复启动")
             return
 
         if client_name not in cls._clients:
@@ -448,7 +451,7 @@ class RabbitMQService:
             if asyncio.get_event_loop().time() - start_time > cls.CONSUMER_START_TIMEOUT:
                 raise TimeoutError(f"等待客户端 '{client_name}' 连接超时")
 
-            logger.debug(f"等待客户端 '{client_name}' 连接就绪...")
+            logger.info(f"等待客户端 '{client_name}' 连接就绪...")
             await asyncio.sleep(1)
 
         # 创建停止事件
@@ -554,7 +557,7 @@ class RabbitMQService:
         if app_name and f"{queue_name}.{app_name}" in cls._sender_client_names:
             return cls._clients.get(f"{queue_name}.{app_name}")
 
-        logger.debug(f"未找到发送器 '{queue_name}'")
+        logger.info(f"未找到发送器 '{queue_name}'")
         return None
 
     @classmethod
@@ -648,7 +651,7 @@ class RabbitMQService:
             raise
 
     @classmethod
-    async def shutdown(cls, timeout: float = 10.0) -> None:
+    async def shutdown(cls, timeout: float = 15.0) -> None:
         """优雅关闭所有资源（新增连接池关闭逻辑）"""
         start_time = asyncio.get_event_loop().time()
         logger.info("开始关闭RabbitMQ服务...")
